@@ -15,7 +15,7 @@ test_that("unequal sizes", {
   expect_format_equal(
     format(x),
     c(
-      "blob[4.00 B]",
+      "blob[4 B]",
       "blob[2.05 kB]",
       "blob[1.05 MB]"
     )
@@ -24,7 +24,7 @@ test_that("unequal sizes", {
   expect_format_equal(
     format(x, trim = FALSE),
     c(
-      "blob[4.00 B]",
+      "blob[    4 B]",
       "blob[2.05 kB]",
       "blob[1.05 MB]"
     )
@@ -45,3 +45,20 @@ test_that("similar sizes", {
     )
   )
 })
+
+test_that("empty", {
+  x <- blob()
+
+  expect_format_equal(
+    format(x),
+    character()
+  )
+})
+
+test_that("output", {
+  skip_on_cran()
+
+  x <- blob(raw(2 ** 2), raw(2 ** 11), raw(2 ** 20))
+
+  expect_known_output(print(x), "blob.txt")
+})
